package com.sy.trustypay.util;

import java.io.InputStream;

import com.sy.trustypay.util.TrustyPayConstants.SignType;

public abstract class TrustyPayConfig {

    /**
     * 域名
     *
     * @return 域名
     */
    public abstract String getDomain();

    /**
     * 获取 App ID
     *
     * @return App ID
     */
    public abstract String getAppID();


    /**
     * 获取 Mch ID
     *
     * @return Mch ID
     */
    public abstract String getMchID();


    /**
     * 获取 API 密钥
     *
     * @return API密钥
     */
    public abstract String getKey();


    /**
     * 获取商户证书内容
     *
     * @return 商户证书内容
     */
    public abstract InputStream getCertStream();


    /**
     * 签名方式
     *
     * @return 签名方式
     */
    public abstract SignType getSignType();

    /**
     * 是否使用证书 true CertStream 不能为空
     *
     * @return 是否使用证书
     */
    public abstract boolean getUseCert();

    /**
     * HTTP(S) 连接超时时间，单位毫秒
     *
     * @return
     */
    public int getHttpConnectTimeoutMs() {
        return 6 * 1000;
    }

    /**
     * HTTP(S) 读数据超时时间，单位毫秒
     *
     * @return
     */
    public int getHttpReadTimeoutMs() {
        return 8 * 1000;
    }


}
